Index: webrtc/modules/utility/source/process_thread_impl.h |
diff --git a/webrtc/modules/utility/source/process_thread_impl.h b/webrtc/modules/utility/source/process_thread_impl.h |
index 1c0a0cdfdd71ec421e0ca70e7f73196fa1b5fc36..2855ed9d85038299d1eb0675d490720a29a901e5 100644 |
--- a/webrtc/modules/utility/source/process_thread_impl.h |
+++ b/webrtc/modules/utility/source/process_thread_impl.h |
@@ -12,6 +12,7 @@ |
#define WEBRTC_MODULES_UTILITY_SOURCE_PROCESS_THREAD_IMPL_H_ |
#include <list> |
+#include <memory> |
#include <queue> |
#include "webrtc/base/criticalsection.h" |
@@ -69,9 +70,9 @@ class ProcessThreadImpl : public ProcessThread { |
rtc::CriticalSection lock_; // Used to guard modules_, tasks_ and stop_. |
rtc::ThreadChecker thread_checker_; |
- const rtc::scoped_ptr<EventWrapper> wake_up_; |
- // TODO(pbos): Remove scoped_ptr and stop recreating the thread. |
- rtc::scoped_ptr<rtc::PlatformThread> thread_; |
+ const std::unique_ptr<EventWrapper> wake_up_; |
+ // TODO(pbos): Remove unique_ptr and stop recreating the thread. |
+ std::unique_ptr<rtc::PlatformThread> thread_; |
ModuleList modules_; |
// TODO(tommi): Support delayed tasks. |